@@ -355,7 +355,7 @@ static void complete_from_nicklist(GList **outlist, CHANNEL_REC *channel,
 		if (g_strncasecmp(rec->nick, nick, len) == 0 &&
 		    glist_find_icase_string(*outlist, rec->nick) == NULL) {
 			str = g_strconcat(rec->nick, suffix, NULL);
-			if (completion_lowercase) g_strdown(str);
+			if (completion_lowercase) ascii_strdown(str);
 			if (rec->own)
 				ownlist = g_list_append(ownlist, str);
                         else
@@ -407,7 +407,7 @@ static GList *completion_nicks_nonstrict(CHANNEL_REC *channel,
 		if (g_strncasecmp(str, nick, len) == 0) {
 			tnick = g_strconcat(rec->nick, suffix, NULL);
 			if (completion_lowercase)
-				g_strdown(tnick);
+				ascii_strdown(tnick);
 
 			if (glist_find_icase_string(list, tnick) == NULL)
 				list = g_list_append(list, tnick);
@@ -451,7 +451,7 @@ static GList *completion_channel_nicks(CHANNEL_REC *channel, const char *nick,
 		    rec != channel->ownnick) {
 			str = g_strconcat(rec->nick, suffix, NULL);
 			if (completion_lowercase)
-				g_strdown(str);
+				ascii_strdown(str);
                         if (glist_find_icase_string(list, str) == NULL)
 				list = g_list_append(list, str);
 			else
@@ -632,6 +632,7 @@ static void sig_complete_word(GList **list, WINDOW_REC *window,
 	if (server != NULL && server_ischannel(server, word)) {
 		/* probably completing a channel name */
 		*list = completion_get_channels(window->active_server, word);
+		if (*list != NULL) signal_stop();
                 return;
 	}
 
@@ -1159,6 +1160,7 @@ void chat_completion_init(void)
 	signal_add("complete command server", (SIGNAL_FUNC) sig_complete_connect);
 	signal_add("complete command disconnect", (SIGNAL_FUNC) sig_complete_tag);
 	signal_add("complete command reconnect", (SIGNAL_FUNC) sig_complete_tag);
+	signal_add("complete command window server", (SIGNAL_FUNC) sig_complete_tag);
 	signal_add("complete command topic", (SIGNAL_FUNC) sig_complete_topic);
 	signal_add("complete command away", (SIGNAL_FUNC) sig_complete_away);
 	signal_add("complete command unalias", (SIGNAL_FUNC) sig_complete_unalias);
@@ -1197,6 +1199,7 @@ void chat_completion_deinit(void)
 	signal_remove("complete command server", (SIGNAL_FUNC) sig_complete_connect);
 	signal_remove("complete command disconnect", (SIGNAL_FUNC) sig_complete_tag);
 	signal_remove("complete command reconnect", (SIGNAL_FUNC) sig_complete_tag);
+	signal_remove("complete command window server", (SIGNAL_FUNC) sig_complete_tag);
 	signal_remove("complete command topic", (SIGNAL_FUNC) sig_complete_topic);
 	signal_remove("complete command away", (SIGNAL_FUNC) sig_complete_away);
 	signal_remove("complete command unalias", (SIGNAL_FUNC) sig_complete_unalias);
