@@ -39,7 +39,9 @@
 #include "window-items.h"
 
 #include <signal.h>
+#include <stdlib.h>
 #include <sys/wait.h>
+#include <unistd.h>
 
 GSList *processes;
 static int signal_exec_input;
@@ -197,11 +199,16 @@ static void process_destroy(PROCESS_REC *rec, int status)
 static void processes_killall(int signum)
 {
 	GSList *tmp;
+	int kill_ret;
 
 	for (tmp = processes; tmp != NULL; tmp = tmp->next) {
 		PROCESS_REC *rec = tmp->data;
 
-		kill(rec->pid, signum);
+		kill_ret = kill(-rec->pid, signum);
+		if (kill_ret != 0)
+		        printtext(NULL, NULL, MSGLEVEL_CLIENTERROR,
+		                  "Error sending signal %d to pid %d: %s",
+		                  signum, rec->pid, g_strerror(errno));
 	}
 }
 
@@ -304,9 +311,9 @@ static void process_exec(PROCESS_REC *rec, const char *cmd)
 
 	if (rec->pid != 0) {
 		/* parent process */
-                GIOChannel *outio = g_io_channel_unix_new(in[1]);
+                GIOChannel *outio = g_io_channel_new(in[1]);
 
-		rec->in = g_io_channel_unix_new(out[0]);
+		rec->in = g_io_channel_new(out[0]);
 		rec->out = net_sendbuffer_create(outio, 0);
 
                 close(out[1]);
@@ -317,8 +324,13 @@ static void process_exec(PROCESS_REC *rec, const char *cmd)
 
 	/* child process, try to clean up everything */
 	setsid();
-	setuid(getuid());
-	setgid(getgid());
+
+	if (setuid(getuid()) != 0)
+		_exit(EXIT_FAILURE);
+
+	if (setgid(getgid()) != 0)
+		_exit(EXIT_FAILURE);
+
 	signal(SIGINT, SIG_IGN);
 	signal(SIGQUIT, SIG_DFL);
 
@@ -378,7 +390,7 @@ static void handle_exec(const char *args, GHashTable *optlist,
 	PROCESS_REC *rec;
 	SERVER_REC *target_server;
         char *target, *level;
-	int notice, signum, interactive, target_nick, target_channel;
+	int notice, signum, interactive, target_nick, target_channel, kill_ret;
 
 	/* check that there's no unknown options. we allowed them
 	   because signals can be used as options, but there should be
@@ -445,8 +457,12 @@ static void handle_exec(const char *args, GHashTable *optlist,
 	}
 
 	if (signum != -1) {
-		/* send a signal to process */
-                kill(rec->pid, signum);
+		/* send a signal to process group */
+                kill_ret = kill(-rec->pid, signum);
+                if (kill_ret != 0)
+                        printtext(NULL, NULL, MSGLEVEL_CLIENTERROR,
+                                  "Error sending signal %d to pid %d: %s",
+                                  signum, rec->pid, g_strerror(errno));
                 return;
 	}
 
@@ -529,8 +545,8 @@ static void handle_exec(const char *args, GHashTable *optlist,
 /* SYNTAX: EXEC [-] [-nosh] [-out | -msg <target> | -notice <target>]
 		[-name <name>] <cmd line>
 	   EXEC -out | -window | -msg <target> | -notice <target> |
-		-close | -<signal> <id>
-	   EXEC -in <id> <text to send to process> */
+		-close | -<signal> %<id>
+	   EXEC -in %<id> <text to send to process> */
 static void cmd_exec(const char *data, SERVER_REC *server, WI_ITEM_REC *item)
 {
 	GHashTable *optlist;
